This is the library for GAUFS.
To reproduce the results presented in the paper, as well as the experimental setup used for comparison with alternative method please use the [`paper-reproducibility` branch](https://github.com/salva24/GAUFS/tree/paper-reproducibility) of this repository.